==> nocc-1.8.3.tbz: www/nocc/lang/sl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: sl.php 2190 2010-05-23 19:27:44Z siebrand $
 */

/** Slovenian (Slovenščina)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Borut Mrak <borut.mrak@ijs.si>
 * @author Dbc334
 * @author Smihael
 */

$lang_locale = 'sl_SI.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Uporabniko ime ni bilo vneeno';
$err_passwd_empty = 'Geslo ni bilo vneeno';
$alt_delete = 'Izbriši izbrana sporočila';
$alt_delete_one = 'Izbrii sporočilo';
$alt_new_msg = 'Nova sporočila';
$alt_reply = 'Odgovori';
$alt_reply_all = 'Odgovori vsem';
$alt_forward = 'Naprej';
$alt_next = 'Naprej';
$alt_prev = 'Nazaj';
$title_next_page = 'Naslednja stran';
$title_prev_page = 'Prejšnja stran';
$title_next_msg = 'Naslednji';
$title_prev_msg = 'Prejšnji';
$html_theme_label = 'Tema:';
$html_welcome = 'Dobrodošli v %1$s';
$html_login = 'Prijava';
$html_user_label = 'Uporabnik:';
$html_passwd_label = 'Geslo:';
$html_submit = 'Pošlji';
$html_help = 'Pomoč';
$html_server_label = 'Strežnik:';
$html_wrong = 'Uporabniško ime ali geslo je napačno';
$html_retry = 'Poskusi ponovno';
$html_remember = 'Zapomni si nastavitve';
$html_lang_label = 'Jezik:';
$html_msgperpage_label = 'Sporočil na stran:';
$html_preferences = 'Nastavitve';
$html_full_name_label = 'Polno ime:';
$html_email_address_label = 'E-mail naslov:';
$html_ccself = 'Kopija sebi';
$html_hide_addresses = 'Skrij naslove';
$html_outlook_quoting = 'citiranje v stilu Outlooka';
$html_reply_to = 'Odgovor na';
$html_use_signature = 'Uporabi podpis';
$html_signature = 'Podpis';
$html_signature_label = 'Podpis:';
$html_prefs_updated = 'Nastavitve shranjene';
$html_manage_folders_link = 'Uredi mape IMAP';
$html_manage_filters_link = 'Uredi filtre e-pošte';
$html_use_graphical_smilies = 'Uporabi slikovne smeške';
$html_folders = 'Mape';
$html_folders_create_failed = 'Mape ni bilo mogoče ustvariti!';
$html_folder_rename = 'Preimenuj';
$html_folder_delete = 'Izbriši';
$html_folder_to = 'v';
$html_filter_remove = 'Odstrani';
$html_filter_body = 'Telo sporočila';
$html_filter_subject = 'Zadeva sporočila';
$html_filter_to = 'Polje Za';
$html_filter_cc = 'Polje Kp';
$html_filter_from = 'Polje Od';
$html_reapply_filters = 'Ponovno uveljavi vse filtre';
$html_filter_contains = 'vsebuje';
$html_filter_name = 'Ime filtra';
$html_filter_action = 'Dejanje filtra';
$html_filter_moveto = 'Premakni v';
$html_select_one = '-- Izberite eno --';
$html_and = 'In';
$html_or = 'ali';
$html_move = 'Premakni';
$html_copy = 'Kopiraj';
$html_gotopage = 'Pojdi na stran';
$html_gotofolder = 'Pojdi v mapo';
$html_other_folders = 'Seznam map';
$html_page = 'Stran';
$html_view_header = 'Pokai glavo';
$html_remove_header = 'Skrij glavo';
$html_inbox = 'Prejeto';
$html_new_msg = 'Pii';
$html_reply = 'Odgovori';
$html_reply_all = 'Odgovori vsem';
$html_forward = 'Posreduj';
$html_delete = 'Brii';
$html_new = 'Novo';
$html_mark = 'Izbrii';
$html_att_label = 'Priponka:';
$html_atts_label = 'Priponke:';
$html_unknown = '[neznan]';
$html_attach = 'Pripni';
$html_attach_forget = 'Datoteko morate pripeti pred poiiljanjem sporočila!';
$html_attach_delete = 'Odstrani izbrane';
$html_sort_by = 'Sortiraj po';
$html_sort = 'Sortiraj';
$html_from = 'Od';
$html_from_label = 'Od:';
$html_subject = 'Zadeva';
$html_subject_label = 'Zadeva:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Poslano:';
$html_wrote = 'je napisal(-a)';
$html_size = 'Velikost';
$html_totalsize = 'Skupna velikost';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajtov';
$html_filename = 'Ime datoteke';
$html_to = 'Za';
$html_to_label = 'Za:';
$html_cc = 'Kp';
$html_cc_label = 'Kp:';
$html_bcc_label = 'Skp:';
$html_nosubject = 'Brez zadeve';
$html_send = 'Pošlji';
$html_cancel = 'Prekliči';
$html_no_mail = 'Ni sporočil.';
$html_logout = 'Odjava';
$html_msg = 'Sporočilo';
$html_msgs = 'Sporočil';
$html_configuration = 'Napaka na streniku';
$html_priority = 'Pomembnost';
$html_priority_label = 'Prioriteta:';
$html_lowest = 'Nižja';
$html_low = 'Nizka';
$html_normal = 'Običajna';
$html_high = 'Visoka';
$html_highest = 'Višja';
$html_spam = 'Smetje';
$html_spam_warning = 'To sporočilo je bilo označeno kot smetje (spam).';
$html_select = 'Označi';
$html_loading_image = 'Nalagam sliko';
$html_send_confirmed = 'Vase sporočilo je bilo poslano.';
$html_no_sendaction = 'Napaka: Brez ukaza. Poskusite vključiti JavaScript.';
$html_error_occurred = 'Zgodila se je napaka.';
$html_prefs_file_error = 'Ne morem pisati v datoteko z nastavitvami';
$html_mark_as = 'Označi kot';
$html_read = 'prebrano';
$html_unread = 'neprebrano';
$html_add = 'Dodaj';
$html_contacts = '%1$s stikov';
$html_modify = 'Spremeni';
$html_back = 'Nazaj';
$html_contact_add = 'Dodaj nov stik';
$html_contact_mod = 'Spremeni stik';
$html_contact_first = 'Ime';
$html_contact_last = 'Priimek';
$html_contact_nick = 'Vzdevek';
$html_contact_mail = 'E-pošta';
$html_contact_del = 'iz seznama stikov';
$html_contact_count = '%1$d stikov';
$html_del_msg = 'Izbrišem izbrana sporočila?';
$html_down_mail = 'Prenesi';
$original_msg = '-- Izvorno sporočilo --';
$to_empty = 'Polje \'Za:\' ne sme biti prazno!';
$html_images_warning = 'Zavoljo vaše varnosti oddaljene slike niso prikazane.';
$html_images_display = 'Prikaži slike';
$html_smtp_error_no_conn = 'Zveze ni mogoče vzpostaviti';
$html_smtp_error_unexpected = 'Nepričakovan odgovor:';
$lang_invalid_msg_num = 'Pokvarjena številka sporočila';
$html_invalid_email_address = 'Neveljavni e-poštni naslov';
$html_search = 'Iskanje';

==> nocc-1.9.1.tbz: www/nocc/lang/sl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: sl.php 2396 2011-02-14 16:47:29Z siebrand $
 */
/** Slovenian (Slovenščina)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Borut Mrak <borut.mrak@ijs.si>
 * @author Dbc334
 * @author Smihael
 */

$lang_locale = 'sl_SI.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Uporabniško ime ni bilo vneseno';
$err_passwd_empty = 'Geslo ni bilo vneseno';
$alt_delete = 'Izbriši izbrana sporočila';
$alt_delete_one = 'Izbriši sporočilo';
$alt_new_msg = 'Nova sporočila';
$alt_reply = 'Odgovori';
$alt_reply_all = 'Odgovori vsem';
$alt_forward = 'Naprej';
$alt_next = 'Naprej';
$alt_prev = 'Nazaj';
$title_next_page = 'Naslednja stran';
$title_prev_page = 'Prejšnja stran';
$title_next_msg = 'Naslednji';
$title_prev_msg = 'Prejšnji';
$html_theme_label = 'Tema:';
$html_welcome = 'Dobrodošli v %1$s';
$html_login = 'Prijava';
$html_user_label = 'Uporabnik:';
$html_passwd_label = 'Geslo:';
$html_submit = 'Pošlji';
$html_help = 'Pomoč';
$html_server_label = 'Strežnik:';
$html_wrong = 'Uporabniško ime ali geslo je napačno';
$html_retry = 'Poskusi ponovno';
$html_remember = 'Zapomni si nastavitve';
$html_lang_label = 'Jezik:';
$html_msgperpage_label = 'Sporočil na stran:';
$html_preferences = 'Nastavitve';
$html_full_name_label = 'Polno ime:';
$html_email_address_label = 'E-poštni naslov:';
$html_bccself = 'Skp sebi';
$html_hide_addresses = 'Skrij naslove';
$html_outlook_quoting = 'navajanje v stilu Outlooka';
$html_reply_to = 'Odgovor na';
$html_use_signature = 'Uporabi podpis';
$html_signature = 'Podpis';
$html_signature_label = 'Podpis:';
$html_reply_leadin_label = 'Uvod odgovora:';
$html_prefs_updated = 'Nastavitve shranjene';
$html_manage_folders_link = 'Uredi mape IMAP';
$html_manage_filters_link = 'Uredi filtre e-pošte';
$html_use_graphical_smilies = 'Uporabi slikovne smeške';
$html_sent_folder_label = 'Kopiraj poslano e-pošto v namensko mapo:';
$html_trash_folder_label = 'Premakni izbrisano e-pošto v namensko mapo:';
$html_colored_quotes = 'Obarvani navedki';
$html_display_struct = 'Prikaži strukturirano besedilo';
$html_send_html_mail = 'Pošlji e-pošto v obliki HTML';
$html_folders = 'Mape';
$html_folders_create_failed = 'Mape ni bilo mogoče ustvariti!';
$html_folders_sub_failed = 'Ne morem se naročiti na mapo!';
$html_folders_unsub_failed = 'Ne morem se odjaviti od mape!';
$html_folders_rename_failed = 'Mape ni bilo mogoče preimenovati!';
$html_folders_updated = 'Mape so posodobljene';
$html_folder_subscribe = 'Naroči se na';
$html_folder_rename = 'Preimenuj';
$html_folder_create = 'Ustvari novo mapo z imenom';
$html_folder_remove = 'Odjavi se od';
$html_folder_delete = 'Izbriši';
$html_folder_to = 'v';
$html_filter_remove = 'Odstrani';
$html_filter_body = 'Telo sporočila';
$html_filter_subject = 'Zadeva sporočila';
$html_filter_to = 'Polje Za';
$html_filter_cc = 'Polje Kp';
$html_filter_from = 'Polje Od';
$html_filter_change_tip = 'Če želite spremeniti filter, ga preprosto prepišite.';
$html_reapply_filters = 'Ponovno uveljavi vse filtre';
$html_filter_contains = 'vsebuje';
$html_filter_name = 'Ime filtra';
$html_filter_action = 'Dejanje filtra';
$html_filter_moveto = 'Premakni v';
$html_select_one = '-- Izberite eno --';
$html_and = 'In';
$html_new_msg_in = 'Nova sporočila v';
$html_or = 'ali';
$html_move = 'Prestavi';
$html_copy = 'Kopiraj';
$html_messages_to = 'izbrana sporočila v';
$html_gotopage = 'Pojdi na stran';
$html_gotofolder = 'Pojdi v mapo';
$html_other_folders = 'Seznam map';
$html_page = 'Stran';
$html_of = 'od';
$html_view_header = 'Pokaži glavo';
$html_remove_header = 'Skrij glavo';
$html_inbox = 'Prejeto';
$html_new_msg = 'Piši';
$html_reply = 'Odgovori';
$html_reply_short = 'Odg:';
$html_reply_all = 'Odgovori vsem';
$html_forward = 'Posreduj';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Posredovano sporočilo bo poslano kot priloga temu.';
$html_delete = 'Briši';
$html_new = 'Novo';
$html_mark = 'Izbriši';
$html_att_label = 'Priponka:';
$html_atts_label = 'Priponke:';
$html_unknown = '[neznan]';
$html_part_x = 'Del %s';
$html_attach = 'Pripni';
$html_attach_forget = 'Datoteko morate pripeti pred pošiljanjem sporočila!';
$html_attach_delete = 'Odstrani izbrane';
$html_attach_none = 'Izbrati morate datoteko za pripenjanje!';
$html_sort_by = 'Razvrsti po';
$html_sort = 'Razvrsti';
$html_from = 'Od';
$html_from_label = 'Od:';
$html_subject = 'Zadeva';
$html_subject_label = 'Zadeva:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Poslano:';
$html_wrote = 'je napisal(-a)';
$html_size = 'Velikost';
$html_totalsize = 'Skupna velikost';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajtov';
$html_filename = 'Ime datoteke';
$html_to = 'Za';
$html_to_label = 'Za:';
$html_cc = 'Kp';
$html_cc_label = 'Kp:';
$html_bcc_label = 'Skp:';
$html_nosubject = 'Brez zadeve';
$html_send = 'Pošlji';
$html_cancel = 'Prekliči';
$html_no_mail = 'Ni sporočil.';
$html_logout = 'Odjava';
$html_msg = 'Sporočilo';
$html_msgs = 'Sporočil';
$html_configuration = 'Ta strežnik ni dobro nastavljen!';
$html_priority = 'Pomembnost';
$html_priority_label = 'Prioriteta:';
$html_lowest = 'Nižja';
$html_low = 'Nizka';
$html_normal = 'Običajna';
$html_high = 'Visoka';
$html_highest = 'Višja';
$html_flagged = 'Z zastavico';
$html_spam = 'Smetje';
$html_spam_warning = 'To sporočilo je bilo označeno kot smetje (spam).';
$html_receipt = 'Zaprosi za povratnico';
$html_select = 'Označi';
$html_select_all = 'Obrni izbor';
$html_select_contacts = 'Izberite stike';
$html_loading_image = 'Nalagam sliko';
$html_send_confirmed = 'Vase sporočilo je bilo poslano.';
$html_no_sendaction = 'Napaka: Brez ukaza. Poskusite vključiti JavaScript.';
$html_error_occurred = 'Zgodila se je napaka.';
$html_prefs_file_error = 'Ne morem pisati v datoteko z nastavitvami';
$html_wrap = 'Število znakov preloma odhodnega sporočila:';
$html_wrap_none = 'Brez preloma';
$html_usenet_separator = 'Ločilo usenet (»-- \n«) pred podpisom';
$html_mark_as = 'Označi kot';
$html_read = 'prebrano';
$html_unread = 'neprebrano';
$html_encoding_label = 'Kodiranje znakov:';
$html_add = 'Dodaj';
$html_contacts = '%1$s stikov';
$html_modify = 'Spremeni';
$html_back = 'Nazaj';
$html_contact_add = 'Dodaj nov stik';
$html_contact_mod = 'Spremeni stik';
$html_contact_first = 'Ime';
$html_contact_last = 'Priimek';
$html_contact_nick = 'Vzdevek';
$html_contact_mail = 'E-pošta';
$html_contact_list = 'Seznam stikov %1$s';
$html_contact_del = 'iz seznama stikov';
$html_contact_count = '%1$d stikov';
$html_contact_err1 = 'Največje število stikov je »%1$d«';
$html_contact_err2 = 'Ne morete dodati novega stika';
$html_contact_err3 = 'Nimate pravic za dostop do seznama stikov';
$html_contact_none = 'Najti ni bilo mogoče nobenega stika.';
$html_del_msg = 'Izbrišem izbrana sporočila?';
$html_down_mail = 'Prenesi';
$original_msg = '-- Izvorno sporočilo --';
$to_empty = 'Polje \'Za:\' ne sme biti prazno!';
$html_images_warning = 'Zavoljo vaše varnosti oddaljene slike niso prikazane.';
$html_images_display = 'Prikaži slike';
$html_smtp_error_no_conn = 'Zveze ni mogoče vzpostaviti';
$html_smtp_error_unexpected = 'Nepričakovan odgovor:';
$lang_could_not_connect = 'Ne morem se povezati s strežnikom';
$lang_invalid_msg_num = 'Pokvarjena številka sporočila';
$html_file_upload_attack = 'Možni napad z nalaganjem datoteke';
$html_invalid_email_address = 'Neveljavni e-poštni naslov';
$html_invalid_msg_per_page = 'Neveljavno število sporočil na stran';
$html_invalid_wrap_msg = 'Neveljavna dolžina preloma sporočila';
$html_seperate_msg_win = 'Sporočila v ločenem oknu';
$html_err_file_contacts = 'Ne morem odpreti datoteke stikov za zapisovanje.';
$html_session_file_error = 'Ne morem odpreti datoteke seje za zapisovanje.';
$html_login_not_allowed = 'Ta prijava ni dovoljena za povezavo.';
$lang_err_send_delay = 'Med dvema e-poštama morate počakati (%1$d sekund)';
$html_search = 'Iskanje';
